pub struct Logging { /* private fields */ }Expand description
Re-exported public API.
Configures Actix runtime logging for an Application.
Logging::default() enables Caelix’s asynchronous HTTP access log.
Public Caelix type Logging.
Implementations
Sourceimpl Logging
impl Logging
Sourcepub fn info() -> Self
pub fn info() -> Self
Enables Actix-compatible detailed HTTP access logs.
The output includes client address, request line and protocol, status, response size, referrer, user agent, and duration.
Sourcepub fn access_log(self, enabled: bool) -> Self
pub fn access_log(self, enabled: bool) -> Self
Enables or disables HTTP access logging.
Sourcepub fn access_log_enabled(&self) -> bool
pub fn access_log_enabled(&self) -> bool
Runs the access_log_enabled public API operation.